#!/bin/bash
################################################################################
#                                 demo.sh                                      #
#                                                                              #
# Automated demo script for the Ohio Libre Free conference in Columbus Ohio    #
# on December 2 and 3, 2022.                                                   #
#                                                                              #
# Prevents fumbling on the CLI during the presentation. Besides, who wants to  #
# see a bunch of presentation slides when the presentation is about BASH?!     #
#                                                                              #
# NOTE: Can only go forward. Cannot go backwards or enter a slide number.      #
#       Hopefully I can add that capability later but a bit of preplanning     #
#       for that shows it will be a complex task.                              #
#                                                                              #
#------------------------------------------------------------------------------#
#                                                                              #
# You will need to install the following packages for this program.            #
# asciiquarium                                                                 #
# banner                                                                       #
# boxes                                                                        #
# cowsay                                                                       #
# figlet                                                                       #
# lolcat                                                                       #
# neofetch                                                                     #
# sl                                                                           #
#                                                                              #
#                                                                              #
#                                                                              #
# Change History                                                               #
#------------------------------------------------------------------------------#
#   Date         Who                     Description                           #
#-----------  -------- --------------------------------------------------------#
# 02/14/2020  David Both    Original code. Demo automation script for the      #
#                           Open Source 101 conference in Columbia SC          #
# 12/01/2022  David Both    Revised for OLF.                                   #
# 12/02/2022  David Both    Further revised for OLF. Mostly shortened and      #
#                           made more concise.                                 #
#                                                                              #
#                                                                              #
################################################################################
################################################################################
################################################################################
#                                                                              #
#  Copyright (C) 2020. 2022 David Both                                         #
#  LinuxGeek46@both.org                                                        #
#  http://www.both.org                                                         #
#                                                                              #
#  This program is free software; you can redistribute it and/or modify        #
#  it under the terms of the GNU General Public License as published by        #
#  the Free Software Foundation; either version 2 of the License, or           #
#  (at your option) any later version.                                         #
#                                                                              #
#  This program is distributed in the hope that it will be useful,             #
#  but WITHOUT ANY WARRANTY; without even the implied warranty of              #
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
#  GNU General Public License for more details.                                #
#                                                                              #
#  You should have received a copy of the GNU General Public License           #
#  along with this program; if not, write to the Free Software                 #
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA   #
#                                                                              #
################################################################################
################################################################################
################################################################################

################################################################################
# Help                                                                         #
################################################################################
Help()
{
   # Display Help
   echo "Configuring and Using Bash"
   echo
   echo "Syntax: demo.sh [h|g|t|v|V]"
   echo "options:"
   echo "g     Print the GPL license notification."
   echo "h     Print this Help."
   echo "s     Skip over many slides. Must modify code to do this."
   echo "t     Test mode. Don't show images or videos."
   echo "V     Print software version and exit."
   echo
}

################################################################################
# Print the GPL license header                                                 #
################################################################################
gpl()
{
   echo
   echo "################################################################################"
   echo "#  Copyright (C) 2020, 2022, David Both                                        #"
   echo "#  LinuxGeek46@both.org                                                        #"
   echo "#  http://www.both.org                                                         #"
   echo "#                                                                              #"
   echo "#  This program is free software; you can redistribute it and/or modify        #"
   echo "#  it under the terms of the GNU General Public License as published by        #"
   echo "#  the Free Software Foundation; either version 2 of the License, or           #"
   echo "#  (at your option) any later version.                                         #"
   echo "#                                                                              #"
   echo "#  This program is distributed in the hope that it will be useful,             #"
   echo "#  but WITHOUT ANY WARRANTY; without even the implied warranty of              #"
   echo "#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #"
   echo "#  GNU General Public License for more details.                                #"
   echo "#                                                                              #"
   echo "#  You should have received a copy of the GNU General Public License           #"
   echo "#  along with this program; if not, write to the Free Software                 #"
   echo "#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA   #"
   echo "################################################################################"
   echo
}

################################################################################
# Gets simple (Y)es (N)o (Q)uit response from user. Loops until                #
# one of those responses is detected.                                          #
#                                                                              #
# This code is not used in this program but it provides an excellent example   #
# of using a while loop with if-then-elif to accept and examine input.         #
################################################################################
ynq()
{
   # loop until we get a good answer and break out
   while [ $OK = 0 ]
   do
      # Print the message
      echo -n "$message (ynq) "
      # Now get some input
      read input
      # Test the input
      if [ $input = "yes" ] || [ $input = "y" ]
      then
         response="y"
         OK=1
      elif [ $input = "no" ] || [ $input = "n" ]
      then
         response="n"
         OK=1
      elif [ $input = "help" ] || [ $input = "h" ]
      then
         help
      elif [ $input = "q" ] || [ $input = "quit" ]
      then
         Quit
      else
         # Invalid input
         echo "INPUT ERROR: Must be y or n or q in lowercase. Please try again."
      fi
   done
}


################################################################################
# Quit nicely with messages as appropriate                                     #
################################################################################
Quit()
{
   if [ $verbose = 1 ]
      then
      if [ $error = 0 ]
         then
         echo "Program terminated normally"
      else
         echo "Program terminated with error ID $ErrorMsg";
      fi
   fi
   exit $error
}

################################################################################
# Display verbose messages in a common format                                  #
################################################################################
PrintMsg()
{
   if  [ $verbose = 1 ] && [ -n "$Msg" ]
   then
      echo "########## $Msg ##########"
      # Set the message to null
      Msg=""
   fi
}


################################################################################
# Display graphics in okular                                                   #
################################################################################
DispGraphic()
{
   # Do this only if Test mode is off
   if [ $Test == 0 ]
   then
      okular $Pic & > /dev/null 2&>1
      read
   fi
}

################################################################################
# Display video in vlc                                                         #
################################################################################
PlayVideo()
{
   # Do this only if Test mode is off
   if [ $Test == 0 ]
   then
      vlc $Video 2&>1 /dev/null
      read
   fi
}

################################################################################
# Display slides in a box                                                      #
################################################################################
Slide()
{
   # Clear the display
   clear
   # Display the message as a slide in the defined box
   # $Box must be predefined or it will use the default box command type.
   echo -e "$Msg" | boxes -a $Format -s $Width  -d $Box -p $Pad
   read
}

lolSlide()
{
   # Clear the display
   clear
   # Display the message as a slide in the defined box
   # $Box must be predefined or it will use the default box command type.
   figlet -c -f banner $Msg | boxes -d $Box | lolcat
   read
}

################################################################################
# Display code as is with indents and all                                      #
################################################################################
Code()
{
   # Clear the screen
   clear
   # Use $Msg variable but keeps basic text formatting
   cat <<EOF
################################################################################
$Msg
################################################################################
EOF
   read
}

################################################################################
# Display command, do it amd then wait for Enter key to be pressed for the     #
# next command.                                                                #
################################################################################
DoIt()
{
   # Display the command as if on the CLI
   printf "[$USER@$Host ~]\$ $Command"
   read
   # Perform the command
   eval $Command 
   Command=''
   printf "[$USER@$Host ~]\$ "
   # Wait for Enter key
   read
}

################################################################################
################################################################################
# Main program                                                                 #
################################################################################
################################################################################
# Set initial variables. Keeping this all in one place makes it easier to      #
# keep track of them.                                                          #
################################################################################
badoption=0
# Set the initial box style
Box="shell"
error=0
Format="c"
Host=`echo $HOSTNAME | awk -F . '{print $1}'`
Pad="a1l3"
PresentationPWD=`pwd`
Msg=" "
MyVar=""
Pic=""
RC=0
Release=0
Skip=0
Test=0
verbose=0
version=00.90
Width=80


################################################################################
# Process the input options. Add options as needed.                            #
################################################################################
# Get the options
while getopts ":ghstvV" option; do
   case $option in
      g) # display GPL
         gpl
         Quit;;
      t) # Set test mode
         Test=1;;
      s) # Set skip mode
         Skip=1;;
      v) # Set verbose mode
         verbose=1;;
      V) # Display software version
         echo "Version = $version"
         Quit;;
      h) # display Help
         Help
         Quit;;
     \?) # incorrect option
         badoption=1;;
   esac
done

if [ $badoption = 1 ]
then
   echo "ERROR: Invalid option"
   Help
   verbose=1
   error=1
   ErrorMsg=" 10T"
   Quit $error
fi


################################################################################
################################################################################
# The main body of your program goes here.
################################################################################
################################################################################
# clear the screen
clear
################################################################################
################################################################################
# Use if/then/else to skip over stuff we don't need to see a bazillion times   #
# while creating and testing the presentation.                                 #
################################################################################
################################################################################
if [ $Skip == 0 ]
then


################################################################################
# Use this to do page size setup before starting the rest of the presentation  #
# using Ctrl-+ and Ctrl-                                                       #
################################################################################
Box="shell"
Format="c"
Msg="Configuring and using Bash Setup"
lolSlide

# run this as people are entering the room
asciiquarium

################################################################################
# NOTE: This code violates the principle:                                      #
#   "Keep the data separate from policy."                                      #
################################################################################

clear
Box="shell"
Format="c"
Msg="Configuring and using Bash"
lolSlide

################################################################################
# Show the code
################################################################################
Msg=" The Code
====================================================

figlet -c -f banner \$Msg | boxes -d \$Box | lolcat"
Slide


Box=ian_jones
Format="c"
Msg=" David Both
====================================================

More than 140 published articles
Red Hat On-line Publications
Opensource.com -- Enable SysAdmin -- Architect
Linux Journal

Five books with Apress

http://www.both.org  LinuxGeek46@both.org

Mastodon @LinuxGeek46@linuxrocks.online"
Slide

Box="shell"
Format="l"
Msg=" You might be a SysAdmin if you ...
====================================================

o   Think my books might be a fun read.

o   Like to take things apart to see how they work

o   Use an open source license for your code.

o   Find computers easier to interact with than most humans.

o   Understand the difference between free as in beer and free
.       as in speech when applied to software.

o   Have ever repaired or upgraded your own computer.

o   Leave the covers off your computer because you replace
.       hardware components frequently."
Slide


################################################################################
# My home computer
################################################################################
#
Video="MasterFrame-Build.mp4"
PlayVideo


Box="parchment"
Format="c"
Msg=" The Linux Truth
====================================================

Unix was not designed to stop its users 
from doing stupid things, as that would 
also stop them from doing clever things.

-- Doug Gwyn"
Slide

Box="shell"
Format="l"
Msg=" How I Learned to Use Bash
====================================================

*   Memorized every command in various books"
Slide

Msg=" !!! NOT !!!"
lolSlide

Box="shell"
Format="l"
Msg=" How I Learned to Use Bash -- REALLY!
====================================================

*   Too many commands to memorize

*   Started with basic movement and list commands

*   Learned the rest as needed 

*   Always assume the Linux CLI can do what I want
-      Then search for the solution"
Slide

Msg=" What is the Command-line interface (CLI)
====================================================

Any text mode user interface to the Linux operating system 
that allows the user to type commands and see the results 
as text output."
Slide


Box="shell"
Format="c"
Msg=" CLI Architecture

====================================================

+------------+    +------------+    +------------+    +------------+
|  Operating |    |  Terminal  |    |            |    |  Command   |
|   System   |<==>|  Emulator  |<==>|    Shell   |<==>|  Prompt    |
|            |    |   or VC    |    |            |    |            |
+------------+    +------------+    +------------+    +------------+"
Slide

Box="shell"
Format="l"
Msg=" Command Prompt
====================================================

Command prompt - a string of characters with a cursor 
which may be flashing - prompting you to enter a command

[student@studentvm1 ~]█ "
Slide

Box="shell"
Format="l"
Msg=" What is a Shell?
====================================================

* Runs in a terminal session

*  Displays the command prompt

*  Interprets the commands typed by the user or SysAdmin 
.    into a form usable by the operating system  

*  Displays command results on the terminal."
Slide


Box="shell"
Format="l"
Msg=" Shell
====================================================

* Shell is best interface for SysAdmins

* No artificial limits

* Easy to automate 

* Default shell for each user specified in /etc/passwd

* Change default login shell using chsh command"
Slide


Msg=" Bash
====================================================

* Default shell for most Linux distros

* Based on Bourne shell 
-   Originally developed by Stephen Bourne at Bell Labs

* Bourne again shell"
Slide

Msg=" Other shells
====================================================

* csh
-   C Shell for C programmers

* tcsh
-   Trusted csh
-   Mostly replaced by Bash

* ksh
-   Written by David Korn
-   Based on Bourne shell with elements of C shell

* zsh 
-   Contains features of csh, tcsh, and ksh"

Slide

Msg=" Running commands
====================================================

* Entering a command launches a new (child) shell
-  Does not terminate the previous one
-  Original remains in background

* Child shell inherits environment from parent shell

* The parent shell waits until the child command is finished

* Control is returned to parent

* Parent continues processing further commands"
Slide



Msg=" Shell Programs - aka Scripts
====================================================

* Scripts a sequence of commands 

* The script runs each command

* Waits for it to finish 

* Then moves on to run the next command"
Slide

Msg=" What is a Console?
====================================================

* The primary terminal connected to a host

* The terminal at which the system operator would sit to enter commands 
    and perform administrative tasks
   
* The terminal on which error messages are displayed"
Slide


Box=shell
Format="c"
Format="l"
Msg=" Old ASR 300 TTY terminal
====================================================

* An old bit of hardware that provides a means of 
. interacting with a mainframe or Unix host

* Dennis Ritchie and Ken Thompson
-   Creators of Unix

* At the PDP system on which they created Unix "
Pic="Terminal-02.jpg"
Slide

# Display the terminal graphic
DispGraphic

Msg=" Newer Terminal
====================================================

* DEC VT100 CRT"
Pic="Terminal-01.jpg"
Slide
# Display the terminal graphic
DispGraphic


Msg=" Virtual console
====================================================

A means to access multiple consoles 
using a single physical system console (KVM)

Ctrl-Alt-F[1-6]"

Pic="VirtualConsole-01.jpg"
Slide
# Display the graphic
DispGraphic


Format="l"
Msg=" Terminal emulator
====================================================

* A software program that emulates a hardware terminal

* Runs on GUI destop

* Many terminal emulators
-   Xterm
-   LXTerminal
-   xfce4-terminal
-   GNOME-terminal
-   Tilix
-   rxvt
-   Terminator
-   Konsole
-   ...etc."
Slide

Msg=" pseudo-terminal 
====================================================

*  A Linux device file to which a terminal emulator is attached
-    Provides an interface with the operating system

*  Device files for pseudo-terminals are located in /dev/pts

*  The device files in /dev/pts are a number for each emulator 

*  The first emulator would be /dev/pts/1, for example."
Slide

Format="l"
Box="cat"
Msg=" Everything is a file
====================================================

Device special files - provide an open operating system 
an interface to the devices that they represent

All Linux device files are located in the /dev directory"
Slide

Command='ls -l /dev/ | less'
DoIt



# Command differs on host david vs host vgr
if [ $Host = "david" ]
then
   Command='sudo dd if=/dev/sda bs=2048 count=8 | less'
else
   Command='sudo dd if=/dev/sda1 bs=2048 count=8 | less'
fi 
DoIt


Msg=" Programs and STDIO
====================================================

* Programs use STDIO for input and output rather than files 
. that are stored on a disk or other recording media

* Primary function is to stream data from the output of one 
.   program, file, or device to the input of another program, 
.   file, or device."
Slide

Box="stone"
Format="c"
Msg=" Everything is a File
====================================================

An interesting demo 

who am I ???

figlet -f banner 'Linux Rocks'  | boxes -d shell | lolcat > <Target>

"
Slide


Box="stone"
Format="l"

Msg=" Shell
====================================================

Interprets the commands typed by the user or SysAdmin into a 
form usable by the operating system. 

Results are returned to the shell program, and displayed on 
the terminal.

The default shell for most Linux distributions is the Bash shell."
Slide

Msg=" Shell
====================================================

* Also programming languages

* Command line programming

* Can be saved as executable files"
Slide

Msg=" Shell Types 
====================================================

* Login:   A shell that results from a login
-   Direct login via virtual console
-   SSH login
-   GUI desktop is a login shell

* No Login:  A shell that is not started by a login
-   screen

* Nologin: Used by Linux system accounts
-   Specifically prevents system login
-   Used for email-only account
-   /usr/sbin/nologin "
Slide



################################################################################
################################################################################
# Beginning of Bash conifiguration file slides. Removed a lot of extraneous    #
# slides to shorten the presentation for OLF. They can be found after the end  #
# of the main part of the program.                                             #
################################################################################
################################################################################
Box="stone"
Format=l
Msg=" Bash configuration files
====================================================

* Global login configuration
-   /etc/bashrc
-   /etc/profile 
-   /etc/profile.d

* Global non-login configuration
-   /etc/bash.bash_logout

* Local login configuration
- Takes precedence over global configuration
-   ~/.bashrc
-   ~/.bash_profile

* Local non-login configuration
-   ~/.bash_history
-   ~/.bash_logout

* Optional - not usually present with Bash
-   ~/.bash_login
-   ~/.profile"
Slide

Pic="BashConfig-01.png"
DispGraphic

Msg="File ~/.bashrc
====================================================
# .bashrc
echo \"Running ~/.bashrc\" <======== Add this line
# Source global definitions
if [ -f /etc/bashrc ]; then
    . /etc/bashrc
fi
# User specific environment
if ! [[ \$PATH =~ \$HOME/.local/bin:\$HOME/bin: ]]
then
    PATH=\$HOME/.local/bin:\$HOME/bin:\$PATH
fi
export PATH

# Uncomment the following line if you dont like 
# the systemctl auto-paging feature:
# export SYSTEMD_PAGER=
# User specific aliases and functions"
Code



################################################################################
################################################################################
# Restore additional Bash configuration samples here if needed.                #
################################################################################
################################################################################


Msg=" Final results with Fedora
====================================================

* Login shell
Last login: Sat Jan 18 14:40:29 2020 from ...
Running /etc/profile
Running Bash config files in /etc/profile.d
Running /etc/bashrc
Running ~/.bash_profile
Running ~/.bashrc
Running /etc/bashrc

* Non-login shell
[dboth@testvm1 ~]$ bash
Running ~/.bashrc
Running /etc/bashrc
Running Bash config files in /etc/profile.d"
Slide

Msg=" Results on POP_os! (Ubuntu)
====================================================

* Login shell
Running /etc/bash.bashrc
Running programs in /etc/profile.d
Running ~/.profile
Running ~/.bashrc
student@voyager:~$

* Non-login shell
student@voyager:~$ bash
Running /etc/bash.bashrc
Running ~/.bashrc
student@voyager:~$ "
Slide


Box="shell"
Format="l"
Msg=" CLI Efficiency
====================================================

* Reduce typing

* Aliases

* CLI recall and editing

* Tab completion

* Expansions

* CLI programs"
Slide


Msg=" Aliases
====================================================

* Replace commands with longer strings

* Reduce typing

alias glances='glances -t1'
alias grep='grep --color=auto'
alias l.='ls -d .* --color=auto'
alias ll='ls -l --color=auto'
alias ls='ls --color=auto'
alias lsn='ls --color=no'
alias mc='. /usr/libexec/mc/mc-wrapper.sh'
alias vi='vim'
alias vim='vim -c \"colorscheme desert\" '
"
Slide

Msg=" Command line recall and editing
====================================================

* Allows recall of previous commands
-   Can be used as-is
-   Or edited to alter the commad

* EMACS mode is default

* Can be changed to vi mode in appropriate config file
-   Local or global
"
Slide




Box="shell"
Format="l"
Msg=" Tab completion
====================================================

* Programmable completion facility for completing partially 
  typed program, host, file, and directory names

* Type the partial command or a file name as an argument to 
  a command, and press the Tab key

* If the host, file, directory, or program exists and the remainder 
  of the name is unique, Bash will complete the entry of the name."
Slide


Box="shell"
Format="l"
Msg="Expansions
====================================================

* Useful tools in programming

* Reduce typing

* Enhance shell logic

* 5 of 7 types
-   Tilde ~
-   Brace expansion {}
-   Pathname expansion *?
-   Command substitution \`\` or \$(command)
-   Arithmetic expansion"
Slide

Msg="Tilde expansion (~)
====================================================

* Shortcut / alias for user home directory
-   \$HOME

ls -la ~ | less"
Slide






################################################################################
# End of stuff to skip                                                         #
################################################################################
fi
################################################################################
################################################################################





Box="shell"
Msg="Brace expansion
====================================================

* A method to use for generating arbitrary strings "
Slide

# Command='echo {String1,string2,string3}'
# DoIt

Command='echo b{ed,olt,ar}s'
DoIt

Command='echo testfile{0,1,2,3,4,5,6,7,8,9}.txt'
DoIt


Box="shell"
Format="l"
clear
Command='touch {my,your,our}.test.file.{000..200}{a..f}.{txt,asc,file,text}'
DoIt

Format="c"
Msg="How Many Files Were Created?
====================================================

"
Slide


Format="c"
Msg="How Many Files Were Created?
====================================================

14,472 "
Slide

Box="shell"
Command='ls | grep test.file | column | less'
DoIt

Format="l"
Box="shell"
Msg="File and Path Name Expansion
====================================================

o Expansion of file globbing patterns using the characters ? and ∗

o Expands into the full names of files and directories which 
  match the pattern"

Command='ls our.*05?.txt | column'
DoIt


Msg="Command substitution
====================================================

* A tool that allows the STDOUT data stream of one command to be 
  used as the argument of another command

* Can generate a list of items to be processed in a loop

* Syntax
-   Backtics  \`command\` 
-   Variable \$(command)"
Slide

Command='for I in 1 2 3 4 5 6 ; do echo $I ; done'
DoIt

Command='for I in `seq 0 9` ; do echo $I ; done'
DoIt


Msg=" Arithmetic expansion
====================================================

* Substitutes the result of an arithmetic expression in a 
. program statement

* Does not require assigning the result to a variable"
Slide

Command='echo $((1+1))'
DoIt

Command='Var1=5 ; Var2=7 ; Var3=$(($Var1*$Var2)) ; echo $Var1, $Var2, $Var3'
DoIt



Msg=" Functions
====================================================

FunctionName(){list of commands}"
Slide

Command='hw(){ echo "Hi there kiddo" ; } ; hw'
DoIt

Box="nuke"
Format="c"
Msg=" Do NOT do this
====================================================

But what does it do?

:(){ :|:& };: "
Slide

Box="shell"
Format="l"



Box="stone"
Format="l"
Msg=" Return codes
====================================================

* All commands return a code indicating success or failure

* Return code of zero (0) indicates success

* Any other return means failure

* Some commands may return one of several non-zero codes
-   Provide more explicit information on cause of failure

* \$? variable contains the return code value
"
Slide

Command="cd /tmp ; echo \$?"
DoIt

Command="cd /root ; echo \$?"
DoIt

cd $PresentationPWD

Box="stone"
Format="l"
Msg=" Control operators
====================================================

* Use return codes to activate logical control operators

* Simple method to control flow of execution

* Easy use on CLI"
Slide

Msg=" && and ||
====================================================

* command1 && command2 
-   If command1 is successful, then run command2. 
-   Ifcommand1 fails for any reason, then command2 is skipped

* command1 || command2
-   If command1 fails, execute command2
-   If command1 succeeds, command2 is skipped

* command1 && command2 || command3
-   If command1 is successful, then run command2 but not command 3
-   If command1 fails for any reason, then skip command2 and run command3
"
Slide

clear
Command='Dir=Testdir ; mkdir $Dir && echo "Directory $Dir created successfully." || echo "ERROR Directory $Dir not created." '
DoIt
# Clean up a bit
rm -rf $Dir
Command='Dir=/root/Testdir ; mkdir $Dir && echo "Directory $Dir created successfully." || echo "ERROR Directory $Dir not created." '
DoIt



################################################################################
# Real SysAdmins don't sudo
################################################################################

clear
Msg="Real Sysadmins Dont sudo"
lolSlide

Msg="Bad sudo
====================================================

* Some distros like Ubuntu force users to use sudo
-   sudo <command> then enter password

* Extra keystrokes means slower and less efficient
-   Lazy Admin always looking for ways to reduce typing

* Users can make same errors
-   It just takes longer

* Much less secure
-   IN MY OPINION! "


Slide

Msg=" Good sudo
====================================================

* Used to allow limited access to programs that require root priviledge
-   Limit users
-   Limit pograms

*  sudo dd if=/dev/sda bs=2048 count=8

"
Slide



Box="girl"
Format="c"
Msg=" Linux Philosophy for SysAdmins
====================================================


################  Automate everything  ################"
Slide


clear
Msg="A SysAdmin is most productive when thinking."
echo $Msg | cowsay -W 65
read

Box="c"
Format="l"
Msg=" Thinking about ...
====================================================

* How to solve existing problems 
* How to avoid future problems
* How to monitor Linux computers 
-   Find clues that anticipate future problems
* How to perform our job more efficiently
* How to automate all of those tasks that need to be performed
-   Whether every day or once a year."
Slide

clear
Msg="  ... But what will the PHB think???" 
echo $Msg | cowthink  -p 
read


Msg=" SysAdmins are next most productive when creating the shell programs that automate the solutions that they have conceived while appearing to be unproductive."

clear
echo $Msg | cowsay -W 65 
read
clear

# Box="stone"
# Format="c"
# Msg="A look at this Bash program"
# Slide

Box="stone"
Format="l"

Command="less demo.sh"
DoIt

################################################################################
################################################################################
################################################################################
################################################################################
#
#

clear
Msg="Automate Everything"
lolSlide

Msg=" Resources
====================================================

The Art of Unix Programming -- Eric Steven Raymond
http://www.catb.org/~esr/writings/taoup/html/

Linux and the Unix Philosopy -- Mike Gancarz
https://flylib.com/books/en/2.506.1/

The Linux Philosophy for SysAdmins -- David Both
http://www.both.org/?page_id=903

The tarball for this session
http://www.both.org/downloads/UsingConfigBash.tar
"
Slide

Msg="Bash man page
====================================================

* Bash command syntax
* List of shell variables
* Programming tools
-   Flow control
-   Functions
* Option arguments
"
Slide

# The steam locomotive
sl

clear
################################################################################
# Do some cleanup
################################################################################
rm *test.file* ; rm -rf Testdir


clear
Msg="Thank You!"
lolSlide


# The final fun thing
Command='asciiquarium'
DoIt



Quit

################################################################################
################################################################################
################################################################################
################################################################################
# End of program
################################################################################
################################################################################
################################################################################
################################################################################
